summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNicoleYarroch <nicole@livio.io>2020-08-17 11:54:53 -0400
committerNicoleYarroch <nicole@livio.io>2020-08-17 11:54:53 -0400
commita1120f0c11628d3f320fd65703e293cf5af3a84e (patch)
tree1ce45e90c76fd3abf47b085e8248b0ce4bc0f59f
parentbe39edd32abe4697128a8a99c963e70bc06f545e (diff)
downloadsdl_ios-a1120f0c11628d3f320fd65703e293cf5af3a84e.tar.gz
Reverting changes to `SDLImageFieldName`
Signed-off-by: NicoleYarroch <nicole@livio.io>
-rw-r--r--SmartDeviceLink/SDLImageFieldName.h46
1 files changed, 21 insertions, 25 deletions
diff --git a/SmartDeviceLink/SDLImageFieldName.h b/SmartDeviceLink/SDLImageFieldName.h
index 91edffc7e..f2fbccd9d 100644
--- a/SmartDeviceLink/SDLImageFieldName.h
+++ b/SmartDeviceLink/SDLImageFieldName.h
@@ -33,85 +33,81 @@
#import "SDLEnum.h"
/**
- The name that identifies the field.
+ The name that identifies the filed. Used in DisplayCapabilities.
- @since SDL 3.0
+ @since SmartDeviceLink 3.0
*/
typedef SDLEnum SDLImageFieldName SDL_SWIFT_ENUM;
/**
- * The image field for Alert
- *
- * @since SDL 6.0
+ The image field for Alert
*/
extern SDLImageFieldName const SDLImageFieldNameAlertIcon;
/**
- * The image field for SoftButton
+ The image field for SoftButton
*/
extern SDLImageFieldName const SDLImageFieldNameSoftButtonImage;
/**
- * The first image field for Choice
+ The first image field for Choice.
*/
extern SDLImageFieldName const SDLImageFieldNameChoiceImage;
/**
- * The secondary image field for Choice
+ The scondary image field for Choice.
*/
extern SDLImageFieldName const SDLImageFieldNameChoiceSecondaryImage;
/**
- * The image field for vrHelpItem
+ The image field for vrHelpItem.
*/
extern SDLImageFieldName const SDLImageFieldNameVoiceRecognitionHelpItem;
/**
- * The image field for Turn
+ The image field for Turn.
*/
extern SDLImageFieldName const SDLImageFieldNameTurnIcon;
/**
- * The image field for the menu icon in SetGlobalProperties
+ The image field for the menu icon in SetGlobalProperties.
*/
extern SDLImageFieldName const SDLImageFieldNameMenuIcon;
-/**
- * The image field for AddCommand
+/** The image field for AddCommand.
+ *
*/
extern SDLImageFieldName const SDLImageFieldNameCommandIcon;
/**
- * The image field for the app icon (set by setAppIcon)
+ The image field for the app icon (set by setAppIcon).
*/
extern SDLImageFieldName const SDLImageFieldNameAppIcon;
-/**
- * The primary image field for Show
+/** The primary image field for Show.
+ *
*/
extern SDLImageFieldName const SDLImageFieldNameGraphic;
-/**
- * The secondary image field for Show
+/** The secondary image field for Show.
*
- * @since SDL 5.0
*/
extern SDLImageFieldName const SDLImageFieldNameSecondaryGraphic;
/**
* The primary image field for ShowConstantTBT
*/
extern SDLImageFieldName const SDLImageFieldNameShowConstantTBTIcon;
/**
- * The secondary image field for ShowConstantTBT
+ The secondary image field for ShowConstant TBT.
*/
extern SDLImageFieldName const SDLImageFieldNameShowConstantTBTNextTurnIcon;
/**
- * The optional image of a destination / location
- *
- * @since SDL 4.0
+ The optional image of a destination / location
+
+ @since SDL 4.0
*/
extern SDLImageFieldName const SDLImageFieldNameLocationImage;
@@ -33,85 +33,81 @@
*/
extern SDLImageFieldName const SDLImageFieldNameSecondaryGraphic;
-/**
- * The primary image field for ShowConstantTBT
+/** The primary image field for ShowConstant TBT.
+ *
*/
extern SDLImageFieldName const SDLImageFieldNameShowConstantTBTIcon;